### R code from vignette source 'OperaMate-vignette.Rnw'

###################################################
### code chunk number 1: style-Sweave
###################################################
if (requireNamespace("BiocStyle", quietly=TRUE)) {
    BiocStyle::latex()
}


###################################################
### code chunk number 2: run_pipeline
###################################################
library(OperaMate) 
data(platemap) 
data(genemap) 
platemap$path <- file.path(system.file("Test",package = "OperaMate"),
                           platemap$path)
(outpath <- tempdir()) 
operaReport <- operaMate(cellformat = "Others",
                         platemap = platemap,genemap = genemap, 
                         Prefix.Barcode = "DSIMGA",outpath=outpath, 
                         expwell = paste0(rep(LETTERS[2:15],each=20),
                           rep(formatC(3:22,width=2,flag=0),times=14)), 
                         ctrwell = c("C23","E23","G23"), 
                         norm.method="Both",BatcheffectSample="exp",
                         email = "cliu@sjtu.edu.cn",david.type="all", 
                         Sig.method="ktsd",width=960,height=960)
names(operaReport)


###################################################
### code chunk number 3: create_one_plate
###################################################
(onePlate <- expData(name = "DSIMGA02-s1",
                     path = file.path( 
                       system.file("Test",package = "OperaMate"),
                       "Matrix", "130504-s1-02.txt" ),
                     rep.id = "s1", exp.id = "DSIMGA02", 
                     format = "Matrix"))


###################################################
### code chunk number 4: create_one_cell
###################################################
(oneCell <- cellData(name = "Average Intensity of Nuclei", 
                     expwell = paste0(rep(LETTERS[2:15],each=20),
                       rep(formatC(3:22,width=2,flag=0),times=14)),
                     ctrwell = c("C23","E23","G23")))


###################################################
### code chunk number 5: import_data
###################################################
## Data importing 
lstPlates <- loadAll(cellformat="Others",platemap=platemap) 
## lstPlates <- loadAll(cellformat="Matrix",
##                         datapath=dirname(platemap$path[4])) 
##Data re-organization 
oneCell <- cellLoad( oneCell,lstPlates )
str(oneCell["origin.data"])


###################################################
### code chunk number 6: norm_cell
###################################################
oneCell <- cellNorm(oneCell, norm.method="Both") 
str(oneCell["norm.data"])


###################################################
### code chunk number 7: batch_methods
###################################################
cellViz(oneCell,exps="exp",type="heatmap",outpath=outpath,gDevice="png")
cellViz(oneCell,exps="exp",type="PCA",outpath=outpath,gDevice="png",width=960,height=960)
cellViz(oneCell,exps="exp",type="median",outpath=outpath,gDevice="png",width=960,height=960)


###################################################
### code chunk number 8: visualize_onePlate
###################################################
plateViz(oneCell,ID="DSIMGA04-s2",gDevice="png",outpath=outpath,width=960,height=960)


###################################################
### code chunk number 9: qc_cell
###################################################
oneCell <- cellQC( oneCell, qth = .05,
                  gDevice="png",outpath=outpath,width=960,height=960)
str(oneCell["qc.data"])
head(oneCell["plate.quality"])


###################################################
### code chunk number 10: sig_detection
###################################################
oneCell <- cellSig(oneCell, method="ktsd",adjust.method="fdr",
                   gDevice="png",outpath=outpath,width=960,height=960) 
names(oneCell["Sig"])


###################################################
### code chunk number 11: sig_vcplot
###################################################
labels <- c("Axin1") 
names(labels) <- c("DSIMGA04:C07")
cellSigplot(oneCell,gDevice="png",outpath=outpath,
            highlight.label=labels,width=960,height=960)


###################################################
### code chunk number 12: sig_analysis
###################################################
chart <- cellSigAnalysis(oneCell,genemap,
                         email="cliu@sjtu.edu.cn", type = "all", 
                         david.terms = list(GO=c("GOTERM_BP_FAT","GOTERM_MF_FAT",
                                              "GOTERM_CC_FAT")), 
                         file = file.path(outpath,"DAVIDReports.txt"),
                         gDevice="png",outpath=outpath,width=960,height=960)
colnames(chart) 


###################################################
### code chunk number 13: report
###################################################
anno.data <- GenerateReport(list(oneCell),genemap,
                            file=file.path(outpath,"OperaMateReports.txt"),
                            gDevice="png",outpath=outpath,width=960,height=960) 
colnames(anno.data) 


###################################################
### code chunk number 14: session_info
###################################################
sessionInfo() 


